@@ -16,18 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -36,12 +36,14 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.metastore_v1alpha.services.dataproc_metastore import pagers
-from google.cloud.metastore_v1alpha.types import metastore
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import DataprocMetastoreTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.metastore_v1alpha.services.dataproc_metastore import pagers
+from google.cloud.metastore_v1alpha.types import metastore
+
+from .transports.base import DEFAULT_CLIENT_INFO, DataprocMetastoreTransport
 from .transports.grpc import DataprocMetastoreGrpcTransport
 from .transports.grpc_asyncio import DataprocMetastoreGrpcAsyncIOTransport
 
@@ -61,7 +63,8 @@ class DataprocMetastoreClientMeta(type):
     _transport_registry["grpc_asyncio"] = DataprocMetastoreGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[DataprocMetastoreTransport]:
         """Returns an appropriate transport class.
 
@@ -189,10 +192,18 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         return self._transport
 
     @staticmethod
-    def backup_path(project: str, location: str, service: str, backup: str,) -> str:
+    def backup_path(
+        project: str,
+        location: str,
+        service: str,
+        backup: str,
+    ) -> str:
         """Returns a fully-qualified backup string."""
         return "projects/{project}/locations/{location}/services/{service}/backups/{backup}".format(
-            project=project, location=location, service=service, backup=backup,
+            project=project,
+            location=location,
+            service=service,
+            backup=backup,
         )
 
     @staticmethod
@@ -205,10 +216,16 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def lake_path(project: str, location: str, lake: str,) -> str:
+    def lake_path(
+        project: str,
+        location: str,
+        lake: str,
+    ) -> str:
         """Returns a fully-qualified lake string."""
         return "projects/{project}/locations/{location}/lakes/{lake}".format(
-            project=project, location=location, lake=lake,
+            project=project,
+            location=location,
+            lake=lake,
         )
 
     @staticmethod
@@ -222,7 +239,10 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     @staticmethod
     def metadata_import_path(
-        project: str, location: str, service: str, metadata_import: str,
+        project: str,
+        location: str,
+        service: str,
+        metadata_import: str,
     ) -> str:
         """Returns a fully-qualified metadata_import string."""
         return "projects/{project}/locations/{location}/services/{service}/metadataImports/{metadata_import}".format(
@@ -242,10 +262,14 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def network_path(project: str, network: str,) -> str:
+    def network_path(
+        project: str,
+        network: str,
+    ) -> str:
         """Returns a fully-qualified network string."""
         return "projects/{project}/global/networks/{network}".format(
-            project=project, network=network,
+            project=project,
+            network=network,
         )
 
     @staticmethod
@@ -257,10 +281,16 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def service_path(project: str, location: str, service: str,) -> str:
+    def service_path(
+        project: str,
+        location: str,
+        service: str,
+    ) -> str:
         """Returns a fully-qualified service string."""
         return "projects/{project}/locations/{location}/services/{service}".format(
-            project=project, location=location, service=service,
+            project=project,
+            location=location,
+            service=service,
         )
 
     @staticmethod
@@ -273,10 +303,16 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def subnetwork_path(project: str, region: str, subnetwork: str,) -> str:
+    def subnetwork_path(
+        project: str,
+        region: str,
+        subnetwork: str,
+    ) -> str:
         """Returns a fully-qualified subnetwork string."""
         return "projects/{project}/regions/{region}/subnetworks/{subnetwork}".format(
-            project=project, region=region, subnetwork=subnetwork,
+            project=project,
+            region=region,
+            subnetwork=subnetwork,
         )
 
     @staticmethod
@@ -289,7 +325,9 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -302,9 +340,13 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -313,9 +355,13 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -324,9 +370,13 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -335,10 +385,14 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -603,12 +657,20 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListServicesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -701,7 +763,12 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -720,7 +787,6 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         r"""Creates a metastore service in a project and
         location.
 
-
         .. code-block:: python
 
             from google.cloud import metastore_v1alpha
@@ -833,7 +899,12 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -956,7 +1027,12 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1073,7 +1149,12 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1177,12 +1258,20 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListMetadataImportsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1275,7 +1364,12 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1294,7 +1388,6 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         r"""Creates a new MetadataImport in a given project and
         location.
 
-
         .. code-block:: python
 
             from google.cloud import metastore_v1alpha
@@ -1406,7 +1499,12 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1433,7 +1531,6 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         Only the description field of MetadataImport is
         supported to be updated.
 
-
         .. code-block:: python
 
             from google.cloud import metastore_v1alpha
@@ -1532,7 +1629,12 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1617,7 +1719,12 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1737,7 +1844,12 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1841,12 +1953,20 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListBackupsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1937,7 +2057,12 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -2064,7 +2189,12 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -2181,7 +2311,12 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -2210,7 +2345,9 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-metastore",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-metastore",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
