@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,20 +14,24 @@
 # limitations under the License.
 #
 from .metastore import (
+    AuxiliaryVersionConfig,
     Backup,
     CreateBackupRequest,
     CreateMetadataImportRequest,
     CreateServiceRequest,
     DatabaseDumpSpec,
     DataCatalogConfig,
+    DataplexConfig,
     DeleteBackupRequest,
     DeleteServiceRequest,
+    EncryptionConfig,
     ExportMetadataRequest,
     GetBackupRequest,
     GetMetadataImportRequest,
     GetServiceRequest,
     HiveMetastoreConfig,
     KerberosConfig,
+    Lake,
     ListBackupsRequest,
     ListBackupsResponse,
     ListMetadataImportsRequest,
@@ -40,6 +44,7 @@ from .metastore import (
     MetadataImport,
     MetadataIntegration,
     MetadataManagementActivity,
+    NetworkConfig,
     OperationMetadata,
     Restore,
     RestoreServiceRequest,
@@ -50,20 +55,24 @@ from .metastore import (
 )
 
 __all__ = (
+    "AuxiliaryVersionConfig",
     "Backup",
     "CreateBackupRequest",
     "CreateMetadataImportRequest",
     "CreateServiceRequest",
     "DatabaseDumpSpec",
     "DataCatalogConfig",
+    "DataplexConfig",
     "DeleteBackupRequest",
     "DeleteServiceRequest",
+    "EncryptionConfig",
     "ExportMetadataRequest",
     "GetBackupRequest",
     "GetMetadataImportRequest",
     "GetServiceRequest",
     "HiveMetastoreConfig",
     "KerberosConfig",
+    "Lake",
     "ListBackupsRequest",
     "ListBackupsResponse",
     "ListMetadataImportsRequest",
@@ -76,6 +85,7 @@ __all__ = (
     "MetadataImport",
     "MetadataIntegration",
     "MetadataManagementActivity",
+    "NetworkConfig",
     "OperationMetadata",
     "Restore",
     "RestoreServiceRequest",
